import { WriterFormat } from './types';
import { SourceComponent } from '../metadata-registry';
export declare type ConvertTransactionState = {
    recompose: {
        [fullName: string]: {
            /**
             * Parent component that children are rolled up into
             */
            component: SourceComponent;
            /**
             * Children to be rolled up into the parent file
             */
            children: SourceComponent[];
        };
    };
};
/**
 * Manages a "global" state over the course of a single metadata conversion call.
 */
export declare class ConvertTransaction {
    readonly state: ConvertTransactionState;
    private readonly finalizers;
    addFinalizer(finalizerCtor: FinalizerConstructor): void;
    /**
     * Call right before the end of a conversion pipeline to execute logic with
     * the transaction state.
     */
    executeFinalizers(): IterableIterator<WriterFormat | WriterFormat[]>;
}
/**
 * Logic to execute at the end of a convert transaction
 */
export interface ConvertTransactionFinalizer {
    finalize(state: ConvertTransactionState): WriterFormat | WriterFormat[];
}
export interface FinalizerConstructor {
    new (): ConvertTransactionFinalizer;
}
export declare class RecompositionFinalizer implements ConvertTransactionFinalizer {
    finalize(state: ConvertTransactionState): WriterFormat[];
}
