"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const decomposedMetadataTransformer_1 = require("./transformers/decomposedMetadataTransformer");
/**
 * Manages a "global" state over the course of a single metadata conversion call.
 */
class ConvertTransaction {
    constructor() {
        this.state = { recompose: {} };
        this.finalizers = new Map();
    }
    addFinalizer(finalizerCtor) {
        if (!this.finalizers.has(finalizerCtor.name)) {
            this.finalizers.set(finalizerCtor.name, new finalizerCtor());
        }
    }
    /**
     * Call right before the end of a conversion pipeline to execute logic with
     * the transaction state.
     */
    *executeFinalizers() {
        for (const finalizer of this.finalizers.values()) {
            yield finalizer.finalize(this.state);
        }
    }
}
exports.ConvertTransaction = ConvertTransaction;
class RecompositionFinalizer {
    finalize(state) {
        const writerData = [];
        for (const parentName of Object.keys(state.recompose)) {
            const parentComponent = state.recompose[parentName].component;
            // only recompose children stored in transaction state
            const children = state.recompose[parentName].children;
            const recomposedXmlObj = decomposedMetadataTransformer_1.DecomposedMetadataTransformer.recompose(children);
            const writerFormat = decomposedMetadataTransformer_1.DecomposedMetadataTransformer.createWriterFormat(parentComponent, recomposedXmlObj);
            writerData.push(writerFormat);
        }
        return writerData;
    }
}
exports.RecompositionFinalizer = RecompositionFinalizer;
//# sourceMappingURL=convertTransaction.js.map