/// <reference types="node" />
import { pipeline as cbPipeline, Readable, Transform, Writable } from 'stream';
import { SourceComponent, MetadataRegistry } from '../metadata-registry';
import { SfdxFileFormat, WriterFormat } from './types';
import { SourcePath } from '../common';
import { ConvertTransaction } from './convertTransaction';
import { JsonMap } from '@salesforce/ts-types';
export declare const pipeline: typeof cbPipeline.__promisify__;
export declare class ComponentReader extends Readable {
    private currentIndex;
    private components;
    constructor(components: SourceComponent[]);
    _read(): void;
}
export declare class ComponentConverter extends Transform {
    private targetFormat;
    private transaction;
    private transformerFactory;
    constructor(targetFormat: SfdxFileFormat, registry: MetadataRegistry, transaction?: ConvertTransaction);
    _transform(chunk: SourceComponent, encoding: string, callback: (err: Error, data: WriterFormat) => void): void;
    /**
     * Called at the end when all components have passed through the pipeline. Finalizers
     * take care of any additional work to be done at this stage e.g. recomposing child components.
     */
    _flush(callback: (err: Error, data?: WriterFormat) => void): void;
}
export declare abstract class ComponentWriter extends Writable {
    protected rootDestination?: SourcePath;
    constructor(rootDestination?: SourcePath);
}
export declare class StandardWriter extends ComponentWriter {
    constructor(rootDestination: SourcePath);
    _write(chunk: WriterFormat, encoding: string, callback: (err?: Error) => void): Promise<void>;
}
export declare class ZipWriter extends ComponentWriter {
    private zip;
    private buffers;
    constructor(rootDestination?: SourcePath);
    _write(chunk: WriterFormat, encoding: string, callback: (err?: Error) => void): Promise<void>;
    _final(callback: (err?: Error) => void): Promise<void>;
    addToZip(contents: string | Readable | Buffer, path: SourcePath): void;
    private getOutputStream;
    get buffer(): Buffer | undefined;
}
/**
 * Convenient wrapper to serialize a js object to XML content. Implemented as a stream
 * to be used as a valid source for ComponentWriters in the conversion pipeline,
 * even though it's not beneficial in the typical way a stream is.
 */
export declare class JsToXml extends Readable {
    private xmlObject;
    constructor(xmlObject: JsonMap);
    _read(): void;
}
