/// <reference types="node" />
import { SourcePath } from '../common/types';
import { Readable } from 'stream';
import { SourceComponent } from '../metadata-registry';
export declare type WriteInfo = {
    relativeDestination: SourcePath;
    source: Readable;
};
export declare type WriterFormat = {
    component: SourceComponent;
    getExtraInfos?: () => Promise<WriteInfo[]>;
    writeInfos: WriteInfo[];
};
declare type PackageName = {
    /**
     * Optional name to give to the package, otherwise one is generated.
     */
    packageName?: string;
};
declare type DirectoryConfig = PackageName & {
    type: 'directory';
    /**
     * Directory path to output the converted package to.
     */
    outputDirectory: SourcePath;
};
declare type ZipConfig = PackageName & {
    type: 'zip';
    /**
     * Directory path to output the zip package to.
     */
    outputDirectory?: SourcePath;
};
/**
 * Transforms metadata component files into different SFDX file formats
 */
export interface MetadataTransformer {
    toMetadataFormat(component: SourceComponent): WriterFormat;
    toSourceFormat(component: SourceComponent): WriterFormat;
}
/**
 * The file format for a set of metadata components.
 *
 * `metadata` - Structure for use with the metadata api.
 *
 * `source` - Friendly for local editing and comitting files to source control.
 */
export declare type SfdxFileFormat = 'metadata' | 'source';
export declare type ConvertOutputConfig = DirectoryConfig | ZipConfig;
export declare type ConvertResult = {
    /**
     * Location of converted package. `Undefined` if `outputDirectory` is omitted from output config.
     */
    packagePath?: SourcePath;
    /**
     * Buffer of converted package. `Undefined` if `outputDirectory` is omitted from zip output config.
     */
    zipBuffer?: Buffer;
};
export {};
