"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const path_1 = require("path");
const metadata_registry_1 = require("../../../src/metadata-registry");
const bundlePath = path_1.join('file', 'path', 'aura', 'mockAuraCmp');
const auraXml = path_1.join(bundlePath, 'mockAuraCmp.cmp-meta.xml');
exports.auraFiles = [
    path_1.join(bundlePath, 'mockAuraCmp.auradoc'),
    path_1.join(bundlePath, 'mockAuraCmp.cmp'),
    path_1.join(bundlePath, 'mockAuraCmp.css'),
    path_1.join(bundlePath, 'mockAuraCmp.design'),
    path_1.join(bundlePath, 'mockAuraCmp.svg'),
    path_1.join(bundlePath, 'mockAuraCmpController.js'),
    path_1.join(bundlePath, 'mockAuraCmpHelper.js'),
    path_1.join(bundlePath, 'mockAuraCmpRenderer.js'),
    auraXml,
];
exports.auraContents = [
    '<aura:documentation><aura:description>Documentation</aura:description><aura:example name="ExampleName" ref="exampleComponentName" label="Label">Example Description</aura:example></aura:documentation>',
    '<aura:component></aura:component>',
    '.THIS {}',
    '<design:component></design:component>',
    '<?xml version="1.0" encoding="UTF-8" standalone="no"?><svg></svg>',
    '({myAction : function(component, event, helper) {}})',
    '({helperMethod : function() {}})',
    '({})',
];
const tree = new metadata_registry_1.VirtualTreeContainer([
    {
        dirPath: bundlePath,
        children: exports.auraFiles.map((f) => path_1.basename(f)),
    },
]);
exports.auraComponent = new metadata_registry_1.SourceComponent({
    type: metadata_registry_1.registryData.types.auradefinitionbundle,
    name: 'mockAuraCmp',
    content: bundlePath,
    xml: auraXml,
}, tree);
exports.testAuraList = [
    {
        DefType: 'COMPONENT',
        FilePath: exports.auraFiles[1],
        Format: 'XML',
        Source: exports.auraContents[1],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'DOCUMENTATION',
        FilePath: exports.auraFiles[0],
        Format: 'XML',
        Source: exports.auraContents[0],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'STYLE',
        FilePath: exports.auraFiles[2],
        Format: 'CSS',
        Source: exports.auraContents[2],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'DESIGN',
        FilePath: exports.auraFiles[3],
        Format: 'XML',
        Source: exports.auraContents[3],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'SVG',
        FilePath: exports.auraFiles[4],
        Format: 'SVG',
        Source: exports.auraContents[4],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'CONTROLLER',
        FilePath: exports.auraFiles[5],
        Format: 'JS',
        Source: exports.auraContents[5],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'HELPER',
        FilePath: exports.auraFiles[6],
        Format: 'JS',
        Source: exports.auraContents[6],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
    {
        DefType: 'RENDERER',
        FilePath: exports.auraFiles[7],
        Format: 'JS',
        Source: exports.auraContents[7],
        AuraDefinitionBundleId: '1dcxxx000000060',
    },
];
exports.createAuraSuccesses = [
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmp.cmp'),
        fullName: 'mockAuraCmp/mockAuraCmp.cmp',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmp.auradoc'),
        fullName: 'mockAuraCmp/mockAuraCmp.auradoc',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmp.css'),
        fullName: 'mockAuraCmp/mockAuraCmp.css',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('file', 'path', 'aura/mockAuraCmp/mockAuraCmp.design'),
        fullName: 'mockAuraCmp/mockAuraCmp.design',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmp.svg'),
        fullName: 'mockAuraCmp/mockAuraCmp.svg',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmpController.js'),
        fullName: 'mockAuraCmp/mockAuraCmpController.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmpHelper.js'),
        fullName: 'mockAuraCmp/mockAuraCmpHelper.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join(bundlePath, 'mockAuraCmpRenderer.js'),
        fullName: 'mockAuraCmp/mockAuraCmpRenderer.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
];
exports.updateCreateSuccesses = [
    {
        changed: true,
        created: false,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmp.cmp'),
        fullName: 'mockAuraCmp/mockAuraCmp.cmp',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: true,
        created: false,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmp.css'),
        fullName: 'mockAuraCmp/mockAuraCmp.css',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: true,
        created: false,
        deleted: false,
        fileName: path_1.join('mockAuraCmp/mockAuraCmp.design'),
        fullName: 'aura/mockAuraCmp/mockAuraCmp.design',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmp.auradoc'),
        fullName: 'mockAuraCmp/mockAuraCmp.auradoc',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmp.svg'),
        fullName: 'mockAuraCmp/mockAuraCmp.svg',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmpController.js'),
        fullName: 'mockAuraCmp/mockAuraCmpController.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmpHelper.js'),
        fullName: 'mockAuraCmp/mockAuraCmpHelper.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
    {
        changed: false,
        created: true,
        deleted: false,
        fileName: path_1.join('aura', 'mockAuraCmp', 'mockAuraCmpRenderer.js'),
        fullName: 'mockAuraCmp/mockAuraCmpRenderer.js',
        success: true,
        componentType: 'AuraDefinitionBundle',
    },
];
//# sourceMappingURL=auraDeployMocks.js.map