"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const testSetup_1 = require("@salesforce/core/lib/testSetup");
const chai_1 = require("chai");
const sinon_1 = require("sinon");
const metadata_registry_1 = require("../../src/metadata-registry");
const client_1 = require("../../src/client");
const deployStrategies_1 = require("../../src/client/deployStrategies");
const i18n_1 = require("../../src/i18n");
const $$ = testSetup_1.testSetup();
describe('Tooling API tests', () => {
    const testMetadataField = {
        apiVersion: '32.0',
        status: 'Active',
    };
    const testData = new testSetup_1.MockTestOrgData();
    let mockConnection;
    let sandboxStub;
    const registryAccess = new metadata_registry_1.RegistryAccess();
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        sandboxStub = sinon_1.createSandbox();
        $$.setConfigStubContents('AuthInfoConfig', {
            contents: yield testData.getConfig(),
        });
        mockConnection = yield core_1.Connection.create({
            authInfo: yield core_1.AuthInfo.create({
                username: testData.username,
            }),
        });
    }));
    afterEach(() => {
        sandboxStub.restore();
    });
    it('should go ahead with deploy for supported types', () => __awaiter(void 0, void 0, void 0, function* () {
        const deployLibrary = new client_1.ToolingApi(mockConnection, registryAccess);
        const component = new metadata_registry_1.SourceComponent({
            type: metadata_registry_1.registryData.types.apexclass,
            name: 'myTestClass',
            xml: 'myTestClass.cls-meta.xml',
            content: 'file/path/myTestClass.cls',
        });
        sandboxStub.stub(metadata_registry_1.RegistryAccess.prototype, 'getComponentsFromPath').returns([component]);
        sandboxStub.stub(deployStrategies_1.ContainerDeploy.prototype, 'buildMetadataField').returns(testMetadataField);
        const mockContainerDeploy = sandboxStub.stub(deployStrategies_1.ContainerDeploy.prototype, 'deploy').resolves({
            id: '123',
            status: "Completed" /* Completed */,
            success: true,
            components: [
                {
                    component,
                    diagnostics: [],
                    status: client_1.ComponentStatus.Changed,
                },
            ],
        });
        yield deployLibrary.deployWithPaths('file/path/myTestClass.cls');
        chai_1.expect(mockContainerDeploy.callCount).to.equal(1);
    }));
    it('should exit deploy for unsupported types', () => __awaiter(void 0, void 0, void 0, function* () {
        sandboxStub.stub(metadata_registry_1.RegistryAccess.prototype, 'getComponentsFromPath').returns([
            new metadata_registry_1.SourceComponent({
                type: metadata_registry_1.registryData.types.flexipage,
                name: '',
                xml: '',
            }),
        ]);
        const deployLibrary = new client_1.ToolingApi(mockConnection, registryAccess);
        try {
            yield deployLibrary.deployWithPaths('file/path/myTestClass.flexipage');
            chai_1.expect.fail('Should have failed');
        }
        catch (e) {
            chai_1.expect(e.message).to.equal(i18n_1.nls.localize('beta_tapi_membertype_unsupported_error', 'FlexiPage'));
            chai_1.expect(e.name).to.be.equal('SourceClientError');
        }
    }));
});
//# sourceMappingURL=toolingApi.test.js.map