"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const path_1 = require("path");
const registry_1 = require("../../mock/registry");
const defaultSourceAdapter_1 = require("../../../src/metadata-registry/adapters/defaultSourceAdapter");
const chai_1 = require("chai");
const metadata_registry_1 = require("../../../src/metadata-registry");
describe('DefaultSourceAdapter', () => {
    it('should return a SourceComponent when given a metadata xml file', () => {
        const path = path_1.join('path', 'to', 'keanus', 'My_Test.keanu-meta.xml');
        const type = registry_1.mockRegistry.types.keanureeves;
        const adapter = new defaultSourceAdapter_1.DefaultSourceAdapter(type, registry_1.mockRegistry);
        chai_1.expect(adapter.getComponent(path)).to.deep.equal(new metadata_registry_1.SourceComponent({
            name: 'My_Test',
            type,
            xml: path,
        }));
    });
    it('should return a SourceComponent when given a content-only metadata file', () => {
        const path = path_1.join('path', 'to', 'keanus', 'My_Test.keanu');
        const type = registry_1.mockRegistry.types.keanureeves;
        const adapter = new defaultSourceAdapter_1.DefaultSourceAdapter(type, registry_1.mockRegistry);
        chai_1.expect(adapter.getComponent(path)).to.deep.equal(new metadata_registry_1.SourceComponent({
            name: 'My_Test',
            type,
            xml: path,
        }));
    });
});
//# sourceMappingURL=defaultSourceAdapter.js.map