"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const registry_1 = require("../../mock/registry");
const chai_1 = require("chai");
const defaultSourceAdapter_1 = require("../../../src/metadata-registry/adapters/defaultSourceAdapter");
const mixedContentSourceAdapter_1 = require("../../../src/metadata-registry/adapters/mixedContentSourceAdapter");
const matchingContentSourceAdapter_1 = require("../../../src/metadata-registry/adapters/matchingContentSourceAdapter");
const bundleSourceAdapter_1 = require("../../../src/metadata-registry/adapters/bundleSourceAdapter");
const decomposedSourceAdapter_1 = require("../../../src/metadata-registry/adapters/decomposedSourceAdapter");
const errors_1 = require("../../../src/errors");
const i18n_1 = require("../../../src/i18n");
const sourceAdapterFactory_1 = require("../../../src/metadata-registry/adapters/sourceAdapterFactory");
const metadata_registry_1 = require("../../../src/metadata-registry");
describe('SourceAdapterFactory', () => {
    const tree = new metadata_registry_1.VirtualTreeContainer([]);
    const factory = new sourceAdapterFactory_1.SourceAdapterFactory(registry_1.mockRegistry, tree);
    // the types being passed to getAdapter don't really matter in these tests. We're
    // just making sure that the adapter is instantiated correctly based on given inputs
    it('Should return DefaultSourceAdapter for type with no assigned AdapterId', () => {
        const type = registry_1.mockRegistry.types.kathybates;
        const adapter = factory.getAdapter(type);
        chai_1.expect(adapter).to.deep.equal(new defaultSourceAdapter_1.DefaultSourceAdapter(type, registry_1.mockRegistry, undefined, tree));
    });
    it('Should return MixedContentSourceAdapter for mixedContent AdapterId', () => {
        const type = registry_1.mockRegistry.types.dwaynejohnson;
        const adapter = factory.getAdapter(type);
        chai_1.expect(adapter).to.deep.equal(new mixedContentSourceAdapter_1.MixedContentSourceAdapter(type, registry_1.mockRegistry, undefined, tree));
        tree;
    });
    it('Should return MatchingContentSourceAdapter for matchingContentFile AdapterId', () => {
        const type = registry_1.mockRegistry.types.keanureeves;
        const adapter = factory.getAdapter(type);
        chai_1.expect(adapter).to.deep.equal(new matchingContentSourceAdapter_1.MatchingContentSourceAdapter(type, registry_1.mockRegistry, undefined, tree));
    });
    it('Should return BundleSourceAdapter for bundle AdapterId', () => {
        const type = registry_1.mockRegistry.types.simonpegg;
        const adapter = factory.getAdapter(type);
        chai_1.expect(adapter).to.deep.equal(new bundleSourceAdapter_1.BundleSourceAdapter(type, registry_1.mockRegistry, undefined, tree));
    });
    it('Should return DecomposedSourceAdapter for decomposed AdapterId', () => {
        const type = registry_1.mockRegistry.types.reginaking;
        const adapter = factory.getAdapter(type);
        chai_1.expect(adapter).to.deep.equal(new decomposedSourceAdapter_1.DecomposedSourceAdapter(type, registry_1.mockRegistry, undefined, tree));
    });
    it('Should throw RegistryError for missing adapter', () => {
        const type = registry_1.mockRegistry.types.genewilder;
        chai_1.assert.throws(() => factory.getAdapter(type), errors_1.RegistryError, i18n_1.nls.localize('error_missing_adapter', [type.name, registry_1.mockRegistry.strategies.genewilder.adapter]));
    });
});
//# sourceMappingURL=sourceAdapterFactory.test.js.map