"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const sinon_1 = require("sinon");
const forceIgnore_1 = require("../../src/metadata-registry/forceIgnore");
const sourceAdapterFactory_1 = require("../../src/metadata-registry/adapters/sourceAdapterFactory");
const treeContainers_1 = require("../../src/metadata-registry/treeContainers");
const registry_1 = require("../mock/registry");
const metadata_registry_1 = require("../../src/metadata-registry");
class RegistryTestUtil {
    constructor(env = sinon_1.createSandbox()) {
        this.env = env;
    }
    restore() {
        this.env.restore();
    }
    createRegistryAccess(virtualFS) {
        return new metadata_registry_1.RegistryAccess(registry_1.mockRegistry, new treeContainers_1.VirtualTreeContainer(virtualFS));
    }
    stubAdapters(config) {
        const getAdapterStub = this.env.stub(sourceAdapterFactory_1.SourceAdapterFactory.prototype, 'getAdapter');
        for (const entry of config) {
            const componentMap = {};
            for (const c of entry.componentMappings) {
                componentMap[c.path] = c.component;
            }
            getAdapterStub.withArgs(entry.type).returns({
                getComponent: (path) => componentMap[path],
                allowMetadataWithContent: () => entry.allowContent,
            });
        }
    }
    stubForceIgnore(config) {
        const forceIgnore = new forceIgnore_1.ForceIgnore();
        const acceptStub = this.env.stub(forceIgnore, 'accepts');
        const denyStub = this.env.stub(forceIgnore, 'denies');
        if (config.deny) {
            config.deny.forEach((path) => {
                denyStub.withArgs(path).returns(true);
                acceptStub.withArgs(path).returns(false);
            });
        }
        if (config.accept) {
            config.accept.forEach((path) => {
                acceptStub.withArgs(path).returns(true);
                denyStub.withArgs(path).returns(false);
            });
        }
        const createIgnoreStub = this.env.stub(forceIgnore_1.ForceIgnore, 'findAndCreate');
        createIgnoreStub.withArgs(config.seed).returns(forceIgnore);
        return forceIgnore;
    }
}
exports.RegistryTestUtil = RegistryTestUtil;
//# sourceMappingURL=registryTestUtil.js.map